@@ -220,6 +220,8 @@ def wide_data_frame_to_triangle(
             )
         ]
     else:
+        if "risk_basis" not in df.columns:
+            df = df.assign(risk_basis=[cell.risk_basis for cell in cell_metadata])
         cells = []
         for idx, group_df in df.groupby(
             ["period_start", "period_end", "evaluation_date", "risk_basis"]
@@ -376,6 +378,8 @@ def long_data_frame_to_triangle(
                         values={field: np.array(value)},
                     )
     else:
+        if "risk_basis" not in df.columns:
+            df = df.assign(risk_basis=[cell.risk_basis for cell in cell_metadata])
         for idx, group_df in df.groupby(
             ["period_start", "period_end", "evaluation_date", "field", "risk_basis"]
             + detail_cols
